==> aws-cdk-scala_2.12-0.10.0-sources.jar: io/burkard/cdk/services/apprunner/CfnService.scala <==
package io.burkard.cdk.services.apprunner

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnService {

  def apply(
    internalResourceId: String,
    sourceConfiguration: software.amazon.awscdk.services.apprunner.CfnService.SourceConfigurationProperty,
    encryptionConfiguration: Option[software.amazon.awscdk.services.apprunner.CfnService.EncryptionConfigurationProperty] = None,
    instanceConfiguration: Option[software.amazon.awscdk.services.apprunner.CfnService.InstanceConfigurationProperty] = None,
    tags: Option[List[_ <: software.amazon.awscdk.CfnTag]] = None,
    serviceName: Option[String] = None,
    healthCheckConfiguration: Option[software.amazon.awscdk.services.apprunner.CfnService.HealthCheckConfigurationProperty] = None,
    autoScalingConfigurationArn: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.apprunner.CfnService =
    software.amazon.awscdk.services.apprunner.CfnService.Builder
      .create(stackCtx, internalResourceId)
      .sourceConfiguration(sourceConfiguration)
      .encryptionConfiguration(encryptionConfiguration.orNull)
      .instanceConfiguration(instanceConfiguration.orNull)
      .tags(tags.map(_.asJava).orNull)
      .serviceName(serviceName.orNull)
      .healthCheckConfiguration(healthCheckConfiguration.orNull)
      .autoScalingConfigurationArn(autoScalingConfigurationArn.orNull)
      .build()
}

==> aws-cdk-scala_2.13-0.22.0-sources.jar: io/burkard/cdk/services/apprunner/CfnService.scala <==
package io.burkard.cdk.services.apprunner

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnService {

  def apply(
    internalResourceId: String,
    sourceConfiguration: software.amazon.awscdk.services.apprunner.CfnService.SourceConfigurationProperty,
    encryptionConfiguration: Option[software.amazon.awscdk.services.apprunner.CfnService.EncryptionConfigurationProperty] = None,
    instanceConfiguration: Option[software.amazon.awscdk.services.apprunner.CfnService.InstanceConfigurationProperty] = None,
    networkConfiguration: Option[software.amazon.awscdk.services.apprunner.CfnService.NetworkConfigurationProperty] = None,
    tags: Option[List[_ <: software.amazon.awscdk.CfnTag]] = None,
    serviceName: Option[String] = None,
    healthCheckConfiguration: Option[software.amazon.awscdk.services.apprunner.CfnService.HealthCheckConfigurationProperty] = None,
    observabilityConfiguration: Option[software.amazon.awscdk.services.apprunner.CfnService.ServiceObservabilityConfigurationProperty] = None,
    autoScalingConfigurationArn: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.apprunner.CfnService =
    software.amazon.awscdk.services.apprunner.CfnService.Builder
      .create(stackCtx, internalResourceId)
      .sourceConfiguration(sourceConfiguration)
      .encryptionConfiguration(encryptionConfiguration.orNull)
      .instanceConfiguration(instanceConfiguration.orNull)
      .networkConfiguration(networkConfiguration.orNull)
      .tags(tags.map(_.asJava).orNull)
      .serviceName(serviceName.orNull)
      .healthCheckConfiguration(healthCheckConfiguration.orNull)
      .observabilityConfiguration(observabilityConfiguration.orNull)
      .autoScalingConfigurationArn(autoScalingConfigurationArn.orNull)
      .build()
}
